@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 
-# Copyright 2005-2006 Messiah College. All rights reserved.
+# Copyright 2005-2007 Messiah College. All rights reserved.
 # Jason Long <jlong@messiah.edu>
 
 # Copyright (c) 2004 Anthony D. Urso. All rights reserved.
@@ -210,7 +210,10 @@ sub check_body_hash
 sub finish_message
 {
 	my $self = shift;
-#	$self->{canon}->finish_message;
+
+	# DKIM requires the signature itself to be committed into the digest.
+	# But first, we need to set the bh= tag on the signature, then
+	# "prettify" it.
 
 	if ($self->{draft_version} eq "01")
 	{
@@ -220,11 +223,6 @@ sub finish_message
 			$self->{Signature}->body_hash(
 					encode_base64($self->{body_hash}, ""));
 		}
-	#	else
-	#	{
-	#		print STDERR "verify: body hash is "
-	#			. encode_base64($self->{body_hash}, "") . "\n";
-	#	}
 	}
 
 	if ($self->{mode} eq "sign")
@@ -241,7 +239,6 @@ sub finish_message
 	}
 
 	$self->{canon}->output($canonicalized);
-	#$self->{header_digest}->add($canonicalized);
 }
 
 =head2 sign() - generates a signature using a private key
@@ -292,3 +289,23 @@ sub verify
 }
 
 1;
+
+__END__
+
+=head1 SEE ALSO
+
+L<Mail::DKIM>
+
+=head1 AUTHOR
+
+Jason Long, E<lt>jlong@messiah.eduE<gt>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) 2005-2007 by Messiah College
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself, either Perl version 5.8.6 or,
+at your option, any later version of Perl 5 you may have available.
+
+=cut
