@@ -15,7 +15,7 @@ use Mail::DKIM::Signature;
 package Mail::DKIM::Common;
 use base "Mail::DKIM::MessageParser";
 use Carp;
-our $VERSION = '0.30';
+our $VERSION = '0.30_1';
 
 sub new
 {
@@ -28,6 +28,11 @@ sub add_header
 	my $self = shift;
 	my ($line) = @_;
 
+	foreach my $algorithm (@{$self->{algorithms}})
+	{
+		$algorithm->add_header($line);
+	}
+
 	if ($line =~ /^([^:]+)\s*:(.*)/s)
 	{
 		my $field_name = lc $1;
