@@ -19,7 +19,7 @@ use Carp;
 
 =head1 NAME
 
-Mail::DKIM::DkSignature - a DomainKeys signature header
+Mail::DKIM::DkSignature - represents a DomainKeys-Signature header
 
 =head1 CONSTRUCTORS
 
@@ -226,6 +226,12 @@ sub check_protocol
 	return ($protocol eq "dns");
 }
 
+sub check_version
+{
+	#DomainKeys doesn't have a v= tag
+	return 1;
+}
+
 sub get_algorithm_class
 {
 	my $self = shift;
@@ -272,7 +278,22 @@ sub identity
 {
 	my $self = shift;
 	croak "cannot change identity on " . ref($self) if @_;
-	return "@" . $self->domain;
+	return $self->{dk_identity};
+}
+
+# init_identity() - initialize the DomainKeys concept of identity
+#
+# The signing identity of a DomainKeys signature is the sender
+# of the message itself, i.e. the address in the Sender/From header.
+# The sender may not be known when the signature object is
+# constructed (since the signature usually precedes the From/Sender
+# header), so use this method when you have the From/Sender value.
+# See also finish_header() in Mail::DKIM::Verifier.
+#
+sub init_identity
+{
+	my $self = shift;
+	$self->{dk_identity} = shift;
 }
 
 sub method
@@ -325,4 +346,22 @@ sub version
 	croak "version not implemented";
 }
 
+=head1 SEE ALSO
+
+L<Mail::DKIM::Signature> for DKIM-Signature headers
+
+=head1 AUTHOR
+
+Jason Long, E<lt>jlong@messiah.eduE<gt>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) 2006-2007 by Messiah College
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself, either Perl version 5.8.6 or,
+at your option, any later version of Perl 5 you may have available.
+
+=cut
+
 1;
