@@ -170,11 +170,19 @@ sub check
 sub check_granularity
 {
 	my $self = shift;
-	my ($identity) = @_;
+	my ($identity, $empty_g_means_wildcard) = @_;
 
 	# check granularity
 	my $g = $self->granularity;
 
+	# yuck- what is this $empty_g_means_wildcard parameter?
+	# well, it turns out that with DomainKeys signatures,
+	# an empty g= is the same as g=*
+	if ($g eq "" && $empty_g_means_wildcard)
+	{
+		$g = "*";
+	}
+
 	# do case-insensitive matching
 	$identity = lc $identity;
 	$g = lc $g;
@@ -193,7 +201,7 @@ sub check_granularity
 			substr($local_part, 0, length($begins)) ne $begins
 			or
 		# the local part must end with $ends
-			substr($local_part, -length($ends)) ne $ends)
+			(length($ends) && substr($local_part, -length($ends)) ne $ends))
 		{
 			$@ = "public key: granularity mismatch\n";
 			return;
