@@ -89,7 +89,7 @@ is written to the referenced string or file handle.
 package Mail::DKIM::Verifier;
 use base "Mail::DKIM::Common";
 use Carp;
-our $VERSION = '0.30';
+our $VERSION = '0.30_1';
 
 sub init
 {
@@ -191,6 +191,17 @@ sub add_signature
 				Debug_Canonicalization => $self->{Debug_Canonicalization},
 			);
 
+	# push through the headers parsed prior to the signature header
+	if ($algorithm->wants_pre_signature_headers)
+	{
+		# Note: this will include the signature header that led to this
+		# "algorithm"...
+		foreach my $head (@{$self->{headers}})
+		{
+			$algorithm->add_header($head);
+		}
+	}
+
 	# save the algorithm
 	$self->{algorithms} ||= [];
 	push @{$self->{algorithms}}, $algorithm;
@@ -335,7 +346,7 @@ sub match_subdomain
 	my ($subdomain, $superdomain) = @_;
 
 	my $tmp = substr(".$subdomain", -1 - length($superdomain));
-	return (".$superdomain" eq $tmp);
+	return (lc ".$superdomain" eq lc $tmp);
 }
 
 #
